==> nextcloud-22.2.6.tgz: nextcloud/apps/dashboard/l10n/pl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pulpit",
    "Dashboard app" : "Aplikacja Pulpit",
    "Show something" : "Pokaż coś",
    "Customize" : "Dostosuj",
    "Edit widgets" : "Edytuj widżety",
    "Get more widgets from the App Store" : "Pobierz więcej widżetów ze sklepu z aplikacjami",
    "Change background image" : "Zmień obraz tła",
    "Weather service" : "Serwis pogodowy",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Ze względu na Twoją prywatność dane pogodowe są pobierane przez serwer Nextcloud w Twoim imieniu. Usługa pogodowa nie otrzymuje żadnych danych osobowych.",
    "Weather data from Met.no" : "Dane pogodowe z Met.no",
    "geocoding with Nominatim" : "geokodowanie z Nominatim",
    "elevation data from OpenTopoData" : "dane wysokościowe z OpenTopoData",
    "Weather" : "Pogoda",
    "Status" : "Status",
    "Good morning" : "Dzień dobry",
    "Good morning, {name}" : "Dzień dobry, {name}",
    "Good afternoon" : "Dzień dobry",
    "Good afternoon, {name}" : "Dzień dobry, {name}",
    "Good evening" : "Dobry wieczór",
    "Good evening, {name}" : "Dobry wieczór, {name}",
    "Hello" : "Witaj",
    "Hello, {name}" : "Witaj, {name}",
    "Pick from Files" : "Wybierz z Plików",
    "Default images" : "Obrazy domyślne",
    "Plain background" : "Zwykłe tło",
    "Insert from {productName}" : "Wstaw z {productName}",
    "Get more widgets from the app store" : "Pobierz więcej widżetów ze sklepu z aplikacjami"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/dashboard/l10n/pl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pulpit",
    "Dashboard app" : "Aplikacja Pulpit",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Rozpocznij dzień z informacjami\n\nPulpit nawigacyjny Nextcloud to Twój punkt początkowy dnia, dając Tobie\nprzegląd nadchodzących spotkań, pilnych wiadomości e-mail, wiadomości\nna czacie, zgłoszeń przychodzących, najnowszych tweetów i wiele więcej!\nUżytkownicy mogą dodawać widżety, które podobają się i zmieniać tło\nwedług własnych upodobań.",
    "Customize" : "Dostosuj",
    "Edit widgets" : "Edytuj widżety",
    "Get more widgets from the App Store" : "Pobierz więcej widżetów z Nextcloud App Store",
    "Change background image" : "Zmień obraz tła",
    "Weather service" : "Serwis pogodowy",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Ze względu na Twoją prywatność dane pogodowe są pobierane przez serwer Nextcloud w Twoim imieniu. Usługa pogodowa nie otrzymuje żadnych danych osobowych.",
    "Weather data from Met.no" : "Dane pogodowe z Met.no",
    "geocoding with Nominatim" : "geokodowanie z Nominatim",
    "elevation data from OpenTopoData" : "dane wysokościowe z OpenTopoData",
    "Weather" : "Pogoda",
    "Status" : "Status",
    "Good morning" : "Dzień dobry",
    "Good morning, {name}" : "Dzień dobry, {name}",
    "Good afternoon" : "Dzień dobry",
    "Good afternoon, {name}" : "Dzień dobry, {name}",
    "Good evening" : "Dobry wieczór",
    "Good evening, {name}" : "Dobry wieczór, {name}",
    "Hello" : "Witaj",
    "Hello, {name}" : "Witaj, {name}",
    "Pick from Files" : "Wybierz z Plików",
    "Default images" : "Obrazy domyślne",
    "Plain background" : "Zwykłe tło",
    "Insert from {productName}" : "Wstaw z {productName}",
    "Show something" : "Pokaż coś"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
